From 9207e6db602ea218aca7d03075339009429280ef Mon Sep 17 00:00:00 2001
From: Praveen Karadugattu <praveenkumar@multicorewareinc.com>
Date: Fri, 17 Apr 2020 19:59:03 +0530
Subject: [PATCH] Fixed some of the wrongly represented cli parameters in the
 docs related to --colormatrix and --videoformat.

---
 doc/reST/cli.rst        |  8 ++++----
 source/common/param.cpp | 12 ++++++------
 source/x265cli.cpp      |  6 +++---
 3 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/doc/reST/cli.rst b/doc/reST/cli.rst
index 1e2765d..0fad45b 100644
--- a/doc/reST/cli.rst
+++ b/doc/reST/cli.rst
@@ -2154,7 +2154,7 @@ VUI fields must be manually specified.
 	2. ntsc
 	3. secam
 	4. mac
-	5. undefined
+	5. unknown
 
 .. option:: --range <full|limited>
 
@@ -2207,15 +2207,15 @@ VUI fields must be manually specified.
 	Specify color matrix setting i.e set the matrix coefficients used in
 	deriving the luma and chroma. Default undefined (not signaled)
 
-	0. GBR
+	0. gbr
 	1. bt709
-	2. undef 
+	2. unknown 
 	3. **reserved**
 	4. fcc
 	5. bt470bg
 	6. smpte170m
 	7. smpte240m
-	8. YCgCo
+	8. ycgco
 	9. bt2020nc
 	10. bt2020c
 	11. smpte2085
diff --git a/source/common/param.cpp b/source/common/param.cpp
index 908400f..b4965ce 100644
--- a/source/common/param.cpp
+++ b/source/common/param.cpp
@@ -1122,7 +1122,7 @@ int x265_param_parse(x265_param* p, const char* name, const char* value)
             p->vui.bEnableOverscanInfoPresentFlag = 1;
             p->vui.bEnableOverscanAppropriateFlag = 1;
         }
-        else if (!strcmp(value, "undef"))
+        else if (!strcmp(value, "unknown"))
             p->vui.bEnableOverscanInfoPresentFlag = 0;
         else
             bError = true;
@@ -1643,23 +1643,23 @@ int x265_check_params(x265_param* param)
           "Sample Aspect Ratio height must be greater than 0");
     CHECK(param->vui.videoFormat < 0 || param->vui.videoFormat > 5,
           "Video Format must be component,"
-          " pal, ntsc, secam, mac or undef");
+          " pal, ntsc, secam, mac or unknown");
     CHECK(param->vui.colorPrimaries < 0
           || param->vui.colorPrimaries > 12
           || param->vui.colorPrimaries == 3,
-          "Color Primaries must be undef, bt709, bt470m,"
+          "Color Primaries must be unknown, bt709, bt470m,"
           " bt470bg, smpte170m, smpte240m, film, bt2020, smpte-st-428, smpte-rp-431 or smpte-eg-432");
     CHECK(param->vui.transferCharacteristics < 0
           || param->vui.transferCharacteristics > 18
           || param->vui.transferCharacteristics == 3,
-          "Transfer Characteristics must be undef, bt709, bt470m, bt470bg,"
+          "Transfer Characteristics must be unknown, bt709, bt470m, bt470bg,"
           " smpte170m, smpte240m, linear, log100, log316, iec61966-2-4, bt1361e,"
           " iec61966-2-1, bt2020-10, bt2020-12, smpte-st-2084, smpte-st-428 or arib-std-b67");
     CHECK(param->vui.matrixCoeffs < 0
           || param->vui.matrixCoeffs > 14
           || param->vui.matrixCoeffs == 3,
-          "Matrix Coefficients must be undef, bt709, fcc, bt470bg, smpte170m,"
-          " smpte240m, GBR, YCgCo, bt2020nc, bt2020c, smpte-st-2085, chroma-nc, chroma-c or ictcp");
+          "Matrix Coefficients must be unknown, bt709, fcc, bt470bg, smpte170m,"
+          " smpte240m, gbr, ycgco, bt2020nc, bt2020c, smpte-st-2085, chroma-nc, chroma-c or ictcp");
     CHECK(param->vui.chromaSampleLocTypeTopField < 0
           || param->vui.chromaSampleLocTypeTopField > 5,
           "Chroma Sample Location Type Top Field must be 0-5");
diff --git a/source/x265cli.cpp b/source/x265cli.cpp
index 05f16b7..4d91b99 100644
--- a/source/x265cli.cpp
+++ b/source/x265cli.cpp
@@ -291,8 +291,8 @@ namespace X265_NS {
         H0("                                 5=40:33, 6=24:11, 7=20:11, 8=32:11, 9=80:33, 10=18:11, 11=15:11,\n");
         H0("                                 12=64:33, 13=160:99, 14=4:3, 15=3:2, 16=2:1 or custom ratio of <int:int>. Default %d\n", param->vui.aspectRatioIdc);
         H1("   --display-window <string>     Describe overscan cropping region as 'left,top,right,bottom' in pixels\n");
-        H1("   --overscan <string>           Specify whether it is appropriate for decoder to show cropped region: undef, show or crop. Default undef\n");
-        H0("   --videoformat <string>        Specify video format from undef, component, pal, ntsc, secam, mac. Default undef\n");
+        H1("   --overscan <string>           Specify whether it is appropriate for decoder to show cropped region: unknown, show or crop. Default undef\n");
+        H0("   --videoformat <string>        Specify video format from unknown, component, pal, ntsc, secam, mac. Default undef\n");
         H0("   --range <string>              Specify black level and range of luma and chroma signals as full or limited Default limited\n");
         H0("   --colorprim <string>          Specify color primaries from  bt709, unknown, reserved, bt470m, bt470bg, smpte170m,\n");
         H0("                                 smpte240m, film, bt2020, smpte428, smpte431, smpte432. Default undef\n");
@@ -994,4 +994,4 @@ namespace X265_NS {
 
 #ifdef __cplusplus
 }
-#endif
\ No newline at end of file
+#endif
-- 
1.8.3.1

